.. _maskedarray:

*************
Masked arrays
*************

Masked arrays are arrays that may have missing or invalid entries.
The :mod:`numpy.ma` module provides a nearly work-alike replacement for numpy
that supports data arrays with masks.

.. index::
   single: masked arrays

.. toctree::
   :maxdepth: 2

   maskedarray.generic
   maskedarray.baseclass
   routines.ma
